==> estateplat-common-1.2.4-20220420.092750-1007-sources.jar: cn/gtmap/estateplat/model/examine/BdcExamineParam.java <==
package cn.gtmap.estateplat.model.examine;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/11/30
 * @description 不动产检查对象
 */
public class BdcExamineParam implements Serializable {

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 不动产登记项目ID
     */
    private String proid;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 上一手项目的权利ID
     */
    private List<String> yQlidList;

    /**
     * @author <a href="mailto:dingweiwei@gtmap.cn">dingweiwei</a>
     * @description 申请类型
     */
    private String sqlx;

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public List<String> getyQlidList() {
        return yQlidList;
    }

    public void setyQlidList(List<String> yQlidList) {
        this.yQlidList = yQlidList;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }
}

==> estateplat-common-1.2.4-20241101.091621-1262-sources.jar: cn/gtmap/estateplat/model/examine/BdcExamineParam.java <==
package cn.gtmap.estateplat.model.examine;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
 * @version 1.0, 2016/11/30
 * @description 不动产检查对象
 */
public class BdcExamineParam implements Serializable {

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 不动产登记项目ID
     */
    private String proid;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 不动产单元号
     */
    private String bdcdyh;

    /**
     * @author <a href="mailto:shenjian@gtmap.cn">shenjian</a>
     * @version 1.0, 2016/11/30
     * @description 上一手项目的权利ID
     */
    private List<String> yQlidList;

    private String sqlx;
    private String djzx;//登记子项

    public String getDjzx() {
        return djzx;
    }

    public void setDjzx(String djzx) {
        this.djzx = djzx;
    }

    public String getSqlx() {
        return sqlx;
    }

    public void setSqlx(String sqlx) {
        this.sqlx = sqlx;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public List<String> getyQlidList() {
        return yQlidList;
    }

    public void setyQlidList(List<String> yQlidList) {
        this.yQlidList = yQlidList;
    }
}
